@@ -256,7 +256,7 @@ class DebuggerBase(object):
     def _worker_wait(self, msg, timeout=DbgEng.WAIT_INFINITE, args=None):
         if timeout == -1:
             timeout = 0xffffffff
-        elif timeout != 0xffffffff:
+        if timeout != 0xffffffff:
             timeout *= 1000
 
         item = WorkItem(msg, timeout, args)
@@ -540,7 +540,7 @@ class DebuggerBase(object):
         self.breakpoints.enable(id)
 
     def bp(self, expr=None, handler=None, windbgcmd=None, oneshot=False,
-            passcount=None, threadid=None):
+            passcount=None, threadid=None, count=0xffffffff):
         """bp(expr,handler,windbgcmd) -> Breakpoint on expression"""
         if expr is None:
             expr = self.reg.get_pc()
@@ -554,7 +554,8 @@ class DebuggerBase(object):
                                     windbgcmd,
                                     oneshot,
                                     passcount,
-                                    threadid)
+                                    threadid,
+                                    count=count)
 
     def ba(self, expr=None, handler=None, windbgcmd=None, oneshot=False,
             passcount=None, threadid=None, size=None, access=None):
